==> ReleaseV1.1.0.zip: wingreportservice/ReportService/ReportConverter/ReportJsonSerializer.cs <==
using System.Text;
using ReportService.Posters;
using WingInterfaceLibrary.DTO.Report;

namespace ReportService.ReportConverter
{
    public class ReportJsonSerializer
    {
        public static string Serialize(string filePath, ReportDTO reportInfo)
        {
            var reportJson = new
            {
                Id = reportInfo.ReportCode,
                Template = Newtonsoft.Json.JsonConvert.DeserializeObject(reportInfo.ReportTemplateJson),
                ElementValues = GetReportElements(reportInfo.ReportDatasJson),
                MeasureElementValues = new List<dynamic>(),
                PreviewImages = new List<dynamic>(),
                CustomTagList = new List<dynamic>(),
            };
            var bytes = new UTF8Encoding().GetBytes(Newtonsoft.Json.JsonConvert.SerializeObject(reportJson));
            FileHelper.SaveFile(filePath, bytes);
            return filePath;
        }

        private static List<IReportElementValue> GetReportElements(string reportDatasJson)
        {
            var elements = new List<IReportElementValue>();
            if (!string.IsNullOrWhiteSpace(reportDatasJson))
            {
                var reportElements = Newtonsoft.Json.JsonConvert.DeserializeObject<List<ReportElementDTO>>(reportDatasJson, new ReportElementDTOConverter());
                foreach (var reportElement in reportElements)
                {
                    if (reportElement is ReportElementStringDTO es)
                    {
                        elements.Add(new ReportElementTag
                        {
                            Id = reportElement.TagId,
                            Name = reportElement.Name,
                        });
                        var value = es?.Value?.ToString() ?? string.Empty;
                        var valueType = "String";
                        if (DateTime.TryParse(value, out DateTime date))
                        {
                            valueType = "Datetime";
                            value = date.ToString("s");
                        }
                        elements.Add(new ReportElementValue
                        {
                            Value = value,
                            ValueType = valueType,
                        });
                    }
                    else if (reportElement is ReportElementArrayDTO ea && ea.Value is List<string> images && ea.Name == "ReportImages")
                    {
                        elements.Add(new ReportElementTag
                        {
                            Id = reportElement.TagId,
                            Name = reportElement.Name,
                        });
                        elements.Add(new ReportElementValue
                        {
                            Value = images.Select(x => new ReportFileImageValue { Value = x }),
                            ValueType = "ImageList",
                        });
                    }
                    else if (reportElement is ReportElementArrayDTO ea2 && ea2.Value is List<string> stringList)
                    {
                        elements.Add(new ReportElementTag
                        {
                            Id = reportElement.TagId,
                            Name = reportElement.Name,
                        });
                        elements.Add(new ReportElementValue
                        {
                            Value = stringList.Select(x => new ReportStringValue { Value = x }),
                            ValueType = "StringList",
                        });
                    }
                }
            }
            return elements;
        }
    }

    public interface IReportElementValue
    {

    }

    public class ReportElementTag : IReportElementValue
    {
        public string Id { get; set; }
        public string Name { get; set; }
        public bool IsDefault { get; set; } = true;
        public string ElementTagType { get; set; } = "General";
    }

    public class ReportElementValue : IReportElementValue
    {
        public object Value { get; set; }
        public string ValueType { get; set; }
    }

    public class ReportFileImageValue
    {
        public string ExamDataId { get; set; } = "";
        public string Value { get; set; }
        public string ValueType { get; set; } = "FileImage";
    }

    public class ReportStringValue
    {
        public string Value { get; set; }
        public string ValueType { get; set; } = "String";
    }
}

==> ReleaseV1.1.1.zip: wingreportservice/ReportService/ReportConverter/ReportJsonSerializer.cs <==
using System.Text;
using ReportService.Posters;
using WingInterfaceLibrary.DTO.Report;

namespace ReportService.ReportConverter
{
    public class ReportJsonSerializer
    {
        public static string Serialize(string filePath, ReportDTO reportInfo)
        {
            var reportJson = new
            {
                Id = reportInfo.ReportCode,
                Template = Newtonsoft.Json.JsonConvert.DeserializeObject(reportInfo.ReportTemplateJson),
                ElementValues = GetReportElements(reportInfo.ReportDatasJson),
                MeasureElementValues = new List<dynamic>(),
                PreviewImages = new List<dynamic>(),
                CustomTagList = new List<dynamic>(),
            };
            var bytes = new UTF8Encoding().GetBytes(Newtonsoft.Json.JsonConvert.SerializeObject(reportJson));
            FileHelper.SaveFile(filePath, bytes);
            return filePath;
        }

        private static List<IReportElementValue> GetReportElements(string reportDatasJson)
        {
            var elements = new List<IReportElementValue>();
            if (!string.IsNullOrWhiteSpace(reportDatasJson))
            {
                var reportElements = Newtonsoft.Json.JsonConvert.DeserializeObject<List<ReportElementDTO>>(reportDatasJson, new ReportElementDTOConverter());
                foreach (var reportElement in reportElements)
                {
                    if (reportElement is ReportElementStringDTO es1 && es1.Name == "ReportImages")
                    {
                        elements.Add(new ReportElementTag
                        {
                            Id = reportElement.TagId,
                            Name = reportElement.Name,
                        });
                        var value = es1?.Value?.ToString() ?? string.Empty;
                        elements.Add(new ReportElementValue
                        {
                            Value = new List<ReportFileImageValue> { new ReportFileImageValue { Value = value } },
                            ValueType = "ImageList",
                        });
                    }
                    else if (reportElement is ReportElementStringDTO es)
                    {
                        elements.Add(new ReportElementTag
                        {
                            Id = reportElement.TagId,
                            Name = reportElement.Name,
                        });
                        var value = es?.Value?.ToString() ?? string.Empty;
                        var valueType = "String";
                        if (DateTime.TryParse(value, out DateTime date))
                        {
                            valueType = "Datetime";
                            value = date.ToString("s");
                        }
                        elements.Add(new ReportElementValue
                        {
                            Value = value,
                            ValueType = valueType,
                        });
                    }
                    else if (reportElement is ReportElementArrayDTO ea && ea.Value is List<string> images && ea.Name == "ReportImages")
                    {
                        elements.Add(new ReportElementTag
                        {
                            Id = reportElement.TagId,
                            Name = reportElement.Name,
                        });
                        elements.Add(new ReportElementValue
                        {
                            Value = images.Select(x => new ReportFileImageValue { Value = x }),
                            ValueType = "ImageList",
                        });
                    }
                    else if (reportElement is ReportElementArrayDTO ea2 && ea2.Value is List<string> stringList)
                    {
                        elements.Add(new ReportElementTag
                        {
                            Id = reportElement.TagId,
                            Name = reportElement.Name,
                        });
                        elements.Add(new ReportElementValue
                        {
                            Value = stringList.Select(x => new ReportStringValue { Value = x }),
                            ValueType = "StringList",
                        });
                    }
                }
            }
            return elements;
        }
    }

    public interface IReportElementValue
    {

    }

    public class ReportElementTag : IReportElementValue
    {
        public string Id { get; set; }
        public string Name { get; set; }
        public bool IsDefault { get; set; } = true;
        public string ElementTagType { get; set; } = "General";
    }

    public class ReportElementValue : IReportElementValue
    {
        public object Value { get; set; }
        public string ValueType { get; set; }
    }

    public class ReportFileImageValue
    {
        public string ExamDataId { get; set; } = "";
        public string Value { get; set; }
        public string ValueType { get; set; } = "FileImage";
    }

    public class ReportStringValue
    {
        public string Value { get; set; }
        public string ValueType { get; set; } = "String";
    }
}
